@@ -11,7 +11,11 @@ Contains the following modules:
 - dli: Defines the Lanczos algorithm and the DoubleLoopInference algorithm.
 """
 
-from .criterions import *
-from .optimize import *
-from .algorithms import *
-from .dli import *
+from .core import *
+from .stopconditions import *
+from .cg import *
+
+# these modules are WIP
+from . import algorithms, criterions, dli, optimize
+
+del core
