@@ -1,4 +1,4 @@
-import ufuncs
+from . import ufuncs
 from . import mpi
 from . import testing
 from .cythonutils import *
