@@ -23,10 +23,13 @@ __all__ = ['all_eq',
            'broadcast_shapes',
            'cast',
            'complex_dtype',
+           'complex_intrinsic_dtype',
            'deprecated',
            'first',
            'first_is_not',
            'float_dtype',
+           'float_intrinsic_dtype',
+           'float_or_complex_dtype',
            'groupbykey',
            'ifirst',
            'ifirst_is_not',
@@ -76,14 +79,43 @@ __all__ = ['all_eq',
 
 
 def deprecated(msg):
-    def decorator(func):
-        @functools.wraps(func)
+    """
+    Decorator for function of class deprecation.
+
+    Example
+    -------
+    >>> @deprecated('use mynewfunc instead.')
+    >>> def myfunc():
+    ...    pass
+
+    >>>@deprecated
+    >>>class MyClass(MyNewClass):
+    >>>    pass
+
+    """
+    def decorator(x):
+        if isinstance(x, type):
+            def __init__(self, *args, **keywords):
+                warn('Class {!r} is deprecated: {}'.format(x.__name__, msg),
+                     PyOperatorsDeprecationWarning)
+                x.__init__.__func__(self, *args, **keywords)
+            __init__.__doc__ = x.__init__.__doc__
+            return type(x.__name__, x.__bases__, {'__init__': __init__,
+                                                  '__doc__': x.__doc__})
+
+        @functools.wraps(x)
         def _(*args, **keywords):
-            warn('{!r} is deprecated: {}'.format(func.__name__, msg),
+            warn('Function {!r} is deprecated: {}'.format(x.__name__, msg),
                  PyOperatorsDeprecationWarning)
-            return func(*args, **keywords)
+            return x(*args, **keywords)
         return _
-    return decorator
+    if isinstance(msg, str):
+        return decorator
+    if not isinstance(msg, type):
+        raise TypeError('Missing deprecation message.')
+    x = msg
+    msg = "Use '{0}' instead.".format(x.__base__.__name__)
+    return decorator(x)
 
 
 # other stuff
@@ -196,6 +228,7 @@ def cast(arrays, dtype=None, order='c'):
 def complex_dtype(dtype):
     """
     Return the complex dtype associated to a numeric dtype.
+    For boolean or integer dtype, the default complex dtype is returned.
 
     Parameter
     ---------
@@ -208,24 +241,58 @@ def complex_dtype(dtype):
     dtype('complex128')
     >>> complex_dtype(np.float32)
     dtype('complex64')
-    >>> complex_dtype(np.float64)
+    >>> complex_dtype('>f8')
+    dtype('>c16')
+
+    """
+    dtype = np.dtype(dtype)
+    if dtype.kind == 'c':
+        return dtype
+    if dtype.kind not in 'biuf':
+        raise TypeError('Non numerical data type.')
+    if dtype.kind != 'f' or dtype.itemsize == 2:
+        return np.dtype(complex)
+    return np.dtype('{0}c{1}'.format(dtype.str[0], dtype.itemsize * 2))
+
+
+def complex_intrinsic_dtype(dtype):
+    """
+    Return the intrinsic complex dtype (complex64 or complex128) associated
+    with a numeric dtype.
+
+    Parameter
+    ---------
+    dtype : dtype
+        The input dtype.
+
+    Example
+    -------
+    >>> complex_intrinsic_dtype(int)
+    dtype('complex128')
+    >>> complex_intrinsic_dtype(np.float32)
+    dtype('complex64')
+    >>> complex_intrinsic_dtype('>f16')
+    dtype('complex128')
+    >>> complex_intrinsic_dtype(np.float128)
+    dtype('complex128')
+    >>> complex_intrinsic_dtype(np.complex256)
     dtype('complex128')
 
     """
-    dtype = float_dtype(dtype)
-    if dtype.kind == 'c':
-        return dtype
-    if dtype == np.float16:
-        if not hasattr(np, 'complex32'):
-            return np.dtype(complex)
-    return np.dtype('complex{}'.format(2 * int(dtype.name[5:])))
+    dtype = np.dtype(dtype)
+    if dtype.kind not in 'biufc':
+        raise TypeError('Non numerical data type.')
+    if dtype.kind in 'biu':
+        return np.dtype(complex)
+    itemsize = dtype.itemsize if dtype.kind == 'c' else dtype.itemsize * 2
+    itemsize = max(8, min(itemsize, 16))
+    return np.dtype('c{0}'.format(itemsize))
 
 
 def float_dtype(dtype):
     """
-    Return the floating dtype associated to a numeric dtype.
-    Unless the input dtype kind is float or complex, the default float dtype
-    is returned.
+    Return the floating dtype associated with a numeric dtype.
+    For boolean or integer dtype, the default float dtype is returned.
 
     Parameter
     ---------
@@ -238,7 +305,75 @@ def float_dtype(dtype):
     dtype('float64')
     >>> float_dtype(np.float32)
     dtype('float32')
+    >>> float_dtype('>f8')
+    dtype('>f8')
     >>> float_dtype(np.complex256)
+    dtype('float128')
+    >>> float_dtype('>c32')
+    dtype('>f16')
+
+    """
+    dtype = np.dtype(dtype)
+    if dtype.kind == 'f':
+        return dtype
+    if dtype.kind not in 'biuc':
+        raise TypeError('Non numerical data type.')
+    if dtype.kind != 'c':
+        return np.dtype(float)
+    return np.dtype('{0}f{1}'.format(dtype.str[0], dtype.itemsize // 2))
+
+
+def float_intrinsic_dtype(dtype):
+    """
+    Return the intrinsic floating dtype (float32 or float64) associated
+    to a numeric dtype.
+
+    Parameter
+    ---------
+    dtype : dtype
+        The input dtype.
+
+    Example
+    -------
+    >>> float_intrinsic_dtype(int)
+    dtype('float64')
+    >>> float_intrinsic_dtype(np.float32)
+    dtype('float32')
+    >>> float_intrinsic_dtype('>f8')
+    dtype('float64')
+    >>> float_intrinsic_dtype(np.float128)
+    dtype('float64')
+    >>> float_intrinsic_dtype(np.complex256)
+    dtype('float64')
+
+    """
+    dtype = np.dtype(dtype)
+    if dtype.kind not in 'biufc':
+        raise TypeError('Non numerical data type.')
+    if dtype.kind in 'biu':
+        return np.dtype(float)
+    itemsize = dtype.itemsize if dtype.kind == 'f' else dtype.itemsize // 2
+    itemsize = max(4, min(itemsize, 8))
+    return np.dtype('f{0}'.format(itemsize))
+
+
+def float_or_complex_dtype(dtype):
+    """
+    Return the float or complex dtype associated to a numeric dtype.
+    For boolean or integer dtype, the default float dtype is returned.
+
+    Parameter
+    ---------
+    dtype : dtype
+        The input dtype.
+
+    Example
+    -------
+    >>> float_or_complex_dtype(int)
+    dtype('float64')
+    >>> float_or_complex_dtype(np.float32)
+    dtype('float32')
+    >>> float_or_complex_dtype(np.complex256)
     dtype('complex256')
 
     """
@@ -608,7 +743,12 @@ def merge_none(a, b):
 
 
 class ndarraywrap(np.ndarray):
-    pass
+    def __array_finalize__(self, obj):
+        if self.ndim == 0:
+            self.__class__ = np.ndarray
+            return
+        if hasattr(obj, '__dict__'):
+            self.__dict__.update(obj.__dict__)
 
 
 def one(dtype):
@@ -1092,8 +1232,8 @@ def zip_broadcast(*args, **keywords):
         raise TypeError('Invalid keyword(s).')
     iter_str = keywords.get('iter_str', True)
     n = max(1 if not isinstance(_, collections.Iterable) or
-            isinstance(_, str) and not iter_str
-            else len(_) if hasattr(_, '__len__') else sys.maxint for _ in args)
+            isinstance(_, str) and not iter_str else len(_)
+            if hasattr(_, '__len__') else sys.maxsize for _ in args)
 
     def wrap(a):
         if not isinstance(a, collections.Iterable) or \
