@@ -12,7 +12,7 @@ from pyoperators import (
 from pyoperators.core import BroadcastingBase
 from pyoperators.flags import linear, square
 from pyoperators.rules import rule_manager
-from pyoperators.utils import float_dtype, product
+from pyoperators.utils import float_or_complex_dtype, product
 from pyoperators.utils.testing import (
     assert_eq, assert_is, assert_is_instance, assert_is_none, assert_is_not,
     assert_is_type, assert_not_in, assert_same)
@@ -363,7 +363,7 @@ def test_dtype():
         if c_ in (IdentityOperator, MaskOperator, ZeroOperator):
             assert_equal(op.dtype, None)
         elif c_ is DiagonalNumexprOperator:
-            assert_equal(op.dtype, float_dtype(t))
+            assert_equal(op.dtype, float_or_complex_dtype(t))
         else:
             assert_equal(op.dtype, t)
 
