@@ -61,10 +61,6 @@ def assert_is_inttuple(shape, msg=''):
 def assert_square(op, msg=''):
     assert_flags(op, 'square', msg)
     assert_eq(op.shapein, op.shapeout)
-    assert_eq(op.reshapein, op.reshapeout)
-    assert_eq(op.validatein, op.validateout)
-    if op.shapein is None:
-        assert_eq(op.toshapein, op.toshapeout)
 
 SHAPES = (None, (), (1,), (3,), (2, 3))
 
@@ -151,6 +147,7 @@ def test_flags():
 def test_symmetric():
     mat = np.matrix([[2, 1], [1, 2]])
 
+    @flags.square
     @flags.symmetric
     class Op(Operator):
         def __init__(self):
@@ -345,12 +342,12 @@ def test_times_mul_or_comp():
         return _.flags.linear
 
     def func(x, y):
-        if np.__version__ < '1.9' and isinstance(x, np.ndarray):
+        if isinstance(x, np.ndarray):
             if isinstance(x, np.matrix):
                 x = DenseOperator(x)
             elif x.ndim > 0:
                 x = DiagonalOperator(x)
-        if scipy.__version__ < '0.14' and isinstance(x, csc_matrix):
+        if isinstance(x, csc_matrix):
             x = SparseOperator(x)
         if x is X.T and (y is np.sqrt or isinstance(y, SquareOperator)) or \
            y is X.T and not isscalarlike(x) and \
