@@ -1,7 +1,8 @@
 from __future__ import division
 import numpy as np
 from numpy.testing import assert_raises
-from pyoperators import DiagonalOperator, HomothetyOperator, Operator, memory
+from pyoperators import (
+    config, DiagonalOperator, HomothetyOperator, memory, Operator)
 from pyoperators.utils import setting
 from pyoperators.core import DeletedOperator
 
@@ -27,7 +28,7 @@ def test_collection_reset():
 
 
 def test_collection():
-    with setting(memory, 'GC_NBYTES_THRESHOLD', 8000):
+    with setting(config, 'GC_NBYTES_THRESHOLD', 8000):
         memory.garbage_collect()
         counter = 0
         for i in range(10):
