@@ -4,17 +4,20 @@ import os
 import time
 
 from contextlib import contextmanager
-from numpy.testing import assert_equal
+from numpy.testing import assert_equal, assert_warns
 from pyoperators import Operator
 from pyoperators.utils import (
-    broadcast_shapes, cast, complex_dtype, first, first_is_not, float_dtype,
-    ifirst, ifirst_is_not, ilast, ilast_is_not, groupbykey,
-    inspect_special_values, interruptible, isscalarlike, zip_broadcast, last,
-    last_is_not, least_greater_multiple, one, omp_num_threads, pi,
-    pool_threading, product, reshape_broadcast, setting, settingerr, split,
-    strenum, strplural, strshape, Timer, uninterruptible, zero)
+    broadcast_shapes, cast, complex_dtype, complex_intrinsic_dtype, deprecated,
+    first, first_is_not, float_dtype, float_intrinsic_dtype,
+    float_or_complex_dtype, ifirst, ifirst_is_not, ilast, ilast_is_not,
+    groupbykey, inspect_special_values, interruptible, isscalarlike,
+    zip_broadcast, last, last_is_not, least_greater_multiple, one,
+    omp_num_threads, pi, pool_threading, product, reshape_broadcast, setting,
+    settingerr, split, strenum, strplural, strshape, Timer, uninterruptible,
+    zero)
 from pyoperators.utils.testing import (
     assert_eq, assert_not_in, assert_raises, assert_same)
+from pyoperators.warnings import PyOperatorsDeprecationWarning
 
 dtypes = [np.dtype(t) for t in (np.bool8, np.uint8, np.int8, np.uint16,
           np.int16, np.uint32, np.int32, np.uint64, np.int64, np.float32,
@@ -27,6 +30,41 @@ def assert_dtype(a, d):
     assert_eq(a.dtype, d)
 
 
+def test_deprecated():
+    class mynewclass(object):
+        def __init__(self, a, b=None):
+            self.a = a
+            self.b = b
+
+    assert_raises(TypeError, deprecated, lambda x: x)
+
+
+    @deprecated('blabla')
+    def myfunc():
+        return 2
+
+
+    @deprecated
+    class myclass1(mynewclass):
+        pass
+
+
+    @deprecated('blabla2')
+    class myclass2(mynewclass):
+        pass
+
+    val = assert_warns(PyOperatorsDeprecationWarning, myfunc)
+    assert_equal(val, 2)
+
+    c = assert_warns(PyOperatorsDeprecationWarning, myclass1, 3, b=2)
+    assert_equal(c.a, 3)
+    assert_equal(c.b, 2)
+
+    c = assert_warns(PyOperatorsDeprecationWarning, myclass2, 3, b=2)
+    assert_equal(c.a, 3)
+    assert_equal(c.b, 2)
+
+
 def test_broadcast_shapes():
     shapes = [((),), ((), ()), ((), (), ()),
               ((1,),), ((), (1,)), ((), (1,), (1,)),
@@ -72,26 +110,60 @@ def test_cast():
 
 
 def test_complex_dtype():
-    dtypes = (str, bool, int, np.uint32, np.float16, np.float32, np.float64,
-              np.float128)
-    expecteds = (None, complex, complex, complex, complex, np.complex64,
-                 np.complex128, np.complex256)
+    dtypes = (str, bool, int, np.uint32,
+              np.float16, np.float32, np.float64, np.float128,
+              np.complex64, np.complex128, np.complex256,
+              '>f2', '>f4', '>f8', '>f16',
+              '>c8', '>c16', '>c32')
+    expecteds = (None, '<c16', '<c16', '<c16',
+                 '<c16', '<c8', '<c16', '<c32',
+                 '<c8', '<c16', '<c32',
+                 '<c16', '>c8', '>c16', '>c32',
+                 '>c8', '>c16', '>c32')
 
     def func(dtype, expected):
         if expected is None:
             assert_raises(TypeError, complex_dtype, dtype)
         else:
             actual = complex_dtype(dtype)
-            assert_eq(actual, expected)
+            assert_eq(actual.str, expected)
+    for dtype, expected in zip(dtypes, expecteds):
+        yield func, dtype, expected
+
+
+def test_complex_intrinsic_dtype():
+    dtypes = (str, bool, int, np.uint32,
+              np.float16, np.float32, np.float64, np.float128,
+              np.complex64, np.complex128, np.complex256,
+              '>f2', '>f4', '>f8', '>f16',
+              '>c8', '>c16', '>c32')
+    expecteds = (None, '<c16', '<c16', '<c16',
+                 '<c8', '<c8', '<c16', '<c16',
+                 '<c8', '<c16', '<c16',
+                 '<c8', '<c8', '<c16', '<c16',
+                 '<c8', '<c16', '<c16')
+
+    def func(dtype, expected):
+        if expected is None:
+            assert_raises(TypeError, complex_dtype, dtype)
+        else:
+            actual = complex_intrinsic_dtype(dtype)
+            assert_eq(actual.str, expected)
     for dtype, expected in zip(dtypes, expecteds):
         yield func, dtype, expected
 
 
 def test_float_dtype():
-    dtypes = (str, bool, int, np.uint32, np.float16, np.float32, np.float64,
-              np.float128)
-    expecteds = (None, float, float, float, np.float16, np.float32, np.float64,
-                 np.float128)
+    dtypes = (str, bool, int, np.uint32,
+              np.float16, np.float32, np.float64, np.float128,
+              np.complex64, np.complex128, np.complex256,
+              '>f2', '>f4', '>f8', '>f16',
+              '>c8', '>c16', '>c32')
+    expecteds = (None, '<f8', '<f8', '<f8',
+                 '<f2', '<f4', '<f8', '<f16',
+                 '<f4', '<f8', '<f16',
+                 '>f2', '>f4', '>f8', '>f16',
+                 '>f4', '>f8', '>f16')
 
     def func(dtype, expected):
         if expected is None:
@@ -103,6 +175,50 @@ def test_float_dtype():
         yield func, dtype, expected
 
 
+def test_float_intrinsic_dtype():
+    dtypes = (str, bool, int, np.uint32,
+              np.float16, np.float32, np.float64, np.float128,
+              np.complex64, np.complex128, np.complex256,
+              '>f2', '>f4', '>f8', '>f16',
+              '>c8', '>c16', '>c32')
+    expecteds = (None, '<f8', '<f8', '<f8',
+                 '<f4', '<f4', '<f8', '<f8',
+                 '<f4', '<f8', '<f8',
+                 '<f4', '<f4', '<f8', '<f8',
+                 '<f4', '<f8', '<f8')
+
+    def func(dtype, expected):
+        if expected is None:
+            assert_raises(TypeError, complex_dtype, dtype)
+        else:
+            actual = float_intrinsic_dtype(dtype)
+            assert_eq(actual.str, expected)
+    for dtype, expected in zip(dtypes, expecteds):
+        yield func, dtype, expected
+
+
+def test_float_or_complex_dtype():
+    dtypes = (str, bool, int, np.uint32,
+              np.float16, np.float32, np.float64, np.float128,
+              np.complex64, np.complex128, np.complex256,
+              '>f2', '>f4', '>f8', '>f16',
+              '>c8', '>c16', '>c32')
+    expecteds = (None, '<f8', '<f8', '<f8',
+                 '<f2', '<f4', '<f8', '<f16',
+                 '<c8', '<c16', '<c32',
+                 '>f2', '>f4', '>f8', '>f16',
+                 '>c8', '>c16', '>c32')
+
+    def func(dtype, expected):
+        if expected is None:
+            assert_raises(TypeError, float_dtype, dtype)
+        else:
+            actual = float_or_complex_dtype(dtype)
+            assert_eq(actual, expected)
+    for dtype, expected in zip(dtypes, expecteds):
+        yield func, dtype, expected
+
+
 def test_first1():
     assert first([1, 2, 3], lambda x: x > 1.5) == 2
     assert last([1, 2, 3], lambda x: x > 1.5) == 3
